==> RSTouchscreenNG-1.4.11.zip: RSTouchscreenNG/projects/pages/src/lib/temperatures.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {RSSelect} from "front-ui";
import {PrinterState, PrintersState, PrinterAction, RepetierState} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-temperatures-component",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *rsIfPrinting="true" title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon>
        <rs-sideicon *rsIfPrinting="false" title="<?php _('Extrude') ?>" [icon]="printerAction.extruderIcon(active.slug,active.activeExtruderId)" link="/move-e-tool"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *rsIfConnected="true" title="<?php _('Status') ?>" icon="rs rs-params" link="/params"></rs-sideicon>
        <rs-empty-sideicon *rsIfConnected="false"></rs-empty-sideicon>
      </rs-side>
      <main>
        <rs-headline><i class="rs rs-chart"></i> <?php _('Temperatures') ?></rs-headline>
        <div class="content-h1">
          <div style="display: table;width:100%;height:99%;margin:0;padding:0; " *ngIf="active && cur.icon">
            <div style="display: table-row;height:1px;">
              <div class="margin-leftright margin-bottom">
                <rs-button (hit)="selectExtruder()" class="secondary full">
                  <i [class]="cur.icon"></i>
                  <h3>{{cur.name}}: {{p|tempFull:1}} <span class="caret"></span></h3>
                </rs-button>
              </div>
            </div>
            <div style="display: table-row;margin:0;padding:0;">
              <rs-temp-graph [extruder]="cur.id"></rs-temp-graph>
            </div>
          </div>
        </div>
      </main>
    </rs-page>
  `
})
export class TemperaturesComponent implements OnDestroy {
  cur: any = {};
  list: any = [];
  p: any = {};
  active: PrinterState = undefined;
  printers$: Observable<PrintersState>;

  private printersSubscription: SubscriptionLike;

  constructor(public printerAction: PrinterAction,
              public rsselect: RSSelect,
              private store: Store<RepetierState>) {
    this.printers$ = store.select("printers");
    this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
      if (p.active) {
        this.active = p.printers[p.active];
        if (!this.active) {
          return;
        }
        if (p.stateTime !== 0 && this.list.length === 0 && this.active.config.general) {
          this.updateList();
        }
        if (this.cur.id < 1000) {
          this.p = this.active.extruders[this.cur.id];
        } else if (this.cur.id < 2000) {
          this.p = this.active.heatedBeds[this.cur.id - 1000];
        } else {
          this.p = this.active.heatedChambers[this.cur.id - 2000];
        }
      } else {
        this.active = undefined;
      }
    });
  }

  ngOnDestroy(): void {
    this.printersSubscription.unsubscribe();
  }

  updateList() {
    if (!this.active) {
      return;
    }
    this.list = [];
    for (const idx of Object.keys(this.active.extruders)) {
      const index = parseInt(idx, 10);
      if (this.active.config.extruders[index].supportTemperature) {
        this.list.push({
          id: idx,
          name: this.printerAction.extruderName(this.active.slug, index) /* "<?php _('Extruder') ?> " + (parseInt(idx, 10) + 1) */,
          icon: this.printerAction.extruderIcon(this.active.slug, index)
        });
      }
    }
    if (this.active.config.heatedBeds.length) {
      this.list.push({id: 1000, name: "<?php _('Heated Bed') ?>", icon: "rs rs-bed"});
    }
    if (this.active.config.heatedChambers.length) {
      this.list.push({id: 2000, name: "<?php _('Heated Chamber') ?>", icon: "rs rs-chamber"});
    }
    if (this.list.length > 0) {
      this.cur = this.list[0];
    }
  }

  selectExtruder() {
    this.rsselect.select(this.list, "name", "<?php _('Select Graph') ?>").then((data) => {
      this.cur = data;
    }, () => {
    });
  }
}

==> RSTouchscreenNG-1.4.14.zip: RSTouchscreenNG/projects/pages/src/lib/temperatures.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {RSSelect} from "front-ui";
import {PrinterState, PrintersState, PrinterAction, RepetierState} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-temperatures-component",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *rsIfPrinting="true" title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon>
        <rs-sideicon *rsIfPrinting="false" title="<?php _('Extrude') ?>" [icon]="printerAction.extruderIcon(active.slug,active.activeExtruderId)" link="/move-e-tool"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *rsIfConnected="true" title="<?php _('Status') ?>" icon="rs rs-params" link="/params"></rs-sideicon>
        <rs-empty-sideicon *rsIfConnected="false"></rs-empty-sideicon>
      </rs-side>
      <main>
        <rs-headline><i class="rs rs-chart"></i> <?php _('Temperatures') ?></rs-headline>
        <div class="content-h1">
          <div style="display: table;width:100%;height:99%;margin:0;padding:0; " *ngIf="active && cur.icon">
            <div style="display: table-row;height:1px;">
              <div class="margin-leftright margin-bottom">
                <rs-button (hit)="selectExtruder()" class="secondary full">
                  <i [class]="cur.icon"></i>
                  <h3>{{cur.name}}: {{p|tempFull:1}} <span class="caret"></span></h3>
                </rs-button>
              </div>
            </div>
            <div style="display: table-row;margin:0;padding:0;">
              <rs-temp-graph [extruder]="cur.id"></rs-temp-graph>
            </div>
          </div>
        </div>
      </main>
    </rs-page>
  `
})
export class TemperaturesComponent implements OnDestroy {
  cur: any = {};
  list: any = [];
  p: any = {};
  active: PrinterState = undefined;
  printers$: Observable<PrintersState>;

  private printersSubscription: SubscriptionLike;

  constructor(public printerAction: PrinterAction,
              public rsselect: RSSelect,
              private store: Store<RepetierState>) {
    this.printers$ = store.select("printers");
    this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
      if (p.active) {
        this.active = p.printers[p.active];
        if (!this.active) {
          return;
        }
        if (p.stateTime !== 0 && this.list.length === 0 && this.active.config.general) {
          this.updateList();
        }
        if (this.cur.id < 1000) {
          this.p = this.active.extruders[this.cur.id];
        } else if (this.cur.id < 2000) {
          this.p = this.active.heatedBeds[this.cur.id - 1000];
        } else {
          this.p = this.active.heatedChambers[this.cur.id - 2000];
        }
      } else {
        this.active = undefined;
      }
    });
  }

  ngOnDestroy(): void {
    this.printersSubscription.unsubscribe();
  }

  updateList() {
    if (!this.active) {
      return;
    }
    this.list = [];
    for (const idx of Object.keys(this.active.extruders)) {
      const index = parseInt(idx, 10);
      if (this.active.config.extruders[index].supportTemperature) {
        this.list.push({
          id: idx,
          name: this.printerAction.extruderName(this.active.slug, index) /* "<?php _('Extruder') ?> " + (parseInt(idx, 10) + 1) */,
          icon: this.printerAction.extruderIcon(this.active.slug, index)
        });
      }
    }
    if (this.active.config.heatedBeds.length) {
      this.list.push({id: 1000, name: this.printerAction.bedName(this.active.slug, 0), icon: "rs rs-bed"});
    }
    if (this.active.config.heatedChambers.length) {
      this.list.push({id: 2000, name: this.printerAction.chamberName(this.active.slug, 0), icon: "rs rs-chamber"});
    }
    if (this.list.length > 0) {
      this.cur = this.list[0];
    }
  }

  selectExtruder() {
    this.rsselect.select(this.list, "name", "<?php _('Select Graph') ?>").then((data) => {
      this.cur = data;
    }, () => {
    });
  }
}
